
#ifndef %{APPNAMEUC}_H
#define %{APPNAMEUC}_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <konqsidebarplugin.h>
#include <tqstring.h>
#include <tdeconfig.h>


class %{APPNAME} : public KonqSidebarPlugin
{
    TQ_OBJECT
  
    
public:
    /**
     * Construct a @ref KonqSidebarPlugin.
     *
     * @param inst The sidebar's tdeinstance class.
     * @param parent The sidebar internal button info class responsible for this plugin.
     * @param widgetParent The container which will contain the plugins widget.
     * @param desktopName The filename of the configuration file.
     * @param name A TQt object name for your plugin.
     **/
     %{APPNAME}(TDEInstance *inst,TQObject *parent,TQWidget *widgetParent, TQString &desktopName, const char* name=0);

    /** destructor */
    ~%{APPNAME}();
    
   virtual TQWidget *getWidget(){return widget;}
   virtual void *provides(const TQString &) {return 0;}

protected:
	/*Example widget only. You use whichever widget you want. You onl have to care that getWidget returns some kind of widget */
	TQLabel *widget;
        virtual void handleURL(const KURL &url);

};

#endif
